==> schedulerx2-worker-1.2.3-sources.jar: com/alibaba/schedulerx/worker/master/persistence/TaskSnapshot.java <==
package com.alibaba.schedulerx.worker.master.persistence;

import java.util.Date;

/**
 *
 * @author xiaomeng.hxm
 */
public class TaskSnapshot {
    private Long job_id;

    private Long job_instance_id;

    private Long task_id;

    private String task_name;

    private Integer status;

    private Float progress;

    private Date gmt_create;

    private Date gmt_modified;

    private String worker;

    private byte[] task_body;

    public Long getJob_id() {
        return job_id;
    }

    public void setJob_id(Long job_id) {
        this.job_id = job_id;
    }

    public Long getJob_instance_id() {
        return job_instance_id;
    }

    public void setJob_instance_id(Long job_instance_id) {
        this.job_instance_id = job_instance_id;
    }

    public Long getTask_id() {
        return task_id;
    }

    public void setTask_id(Long task_id) {
        this.task_id = task_id;
    }

    public String getTask_name() {
        return task_name;
    }

    public void setTask_name(String task_name) {
        this.task_name = task_name;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Float getProgress() {
        return progress;
    }

    public void setProgress(Float progress) {
        this.progress = progress;
    }

    public Date getGmt_create() {
        return gmt_create;
    }

    public void setGmt_create(Date gmt_create) {
        this.gmt_create = gmt_create;
    }

    public Date getGmt_modified() {
        return gmt_modified;
    }

    public void setGmt_modified(Date gmt_modified) {
        this.gmt_modified = gmt_modified;
    }

    public String getWorker() {
        return worker;
    }

    public void setWorker(String worker) {
        this.worker = worker;
    }

    public byte[] getTask_body() {
        return task_body;
    }

    public void setTask_body(byte[] task_body) {
        this.task_body = task_body;
    }
}

==> schedulerx2-worker-1.10.8-sources.jar: com/alibaba/schedulerx/worker/master/persistence/TaskSnapshot.java <==
package com.alibaba.schedulerx.worker.master.persistence;

import java.util.Date;

/**
 *
 * @author xiaomeng.hxm
 */
public class TaskSnapshot {
    private Long job_id;

    private Long job_instance_id;

    private Long task_id;

    private Long batch_no;

    private String task_name;

    private Integer status;

    private Float progress;

    private Date gmt_create;

    private Date gmt_modified;

    private String worker;

    private byte[] task_body;

    public Long getJob_id() {
        return job_id;
    }

    public void setJob_id(Long job_id) {
        this.job_id = job_id;
    }

    public Long getJob_instance_id() {
        return job_instance_id;
    }

    public void setJob_instance_id(Long job_instance_id) {
        this.job_instance_id = job_instance_id;
    }

    public Long getTask_id() {
        return task_id;
    }

    public void setTask_id(Long task_id) {
        this.task_id = task_id;
    }

    public String getTask_name() {
        return task_name;
    }

    public void setTask_name(String task_name) {
        this.task_name = task_name;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Float getProgress() {
        return progress;
    }

    public void setProgress(Float progress) {
        this.progress = progress;
    }

    public Date getGmt_create() {
        return gmt_create;
    }

    public void setGmt_create(Date gmt_create) {
        this.gmt_create = gmt_create;
    }

    public Date getGmt_modified() {
        return gmt_modified;
    }

    public void setGmt_modified(Date gmt_modified) {
        this.gmt_modified = gmt_modified;
    }

    public String getWorker() {
        return worker;
    }

    public void setWorker(String worker) {
        this.worker = worker;
    }

    public byte[] getTask_body() {
        return task_body;
    }

    public void setTask_body(byte[] task_body) {
        this.task_body = task_body;
    }

    public Long getBatch_no() {
        return batch_no;
    }

    public void setBatch_no(Long batch_no) {
        this.batch_no = batch_no;
    }
}
